@@ -17,6 +17,8 @@ import javax.xml.bind.annotation.XmlType;
  *     &lt;enumeration value="UpdateImage"/>
  *     &lt;enumeration value="VHWA"/>
  *     &lt;enumeration value="VisibleRegion"/>
+ *     &lt;enumeration value="RenderCursor"/>
+ *     &lt;enumeration value="MoveCursor"/>
  *   &lt;/restriction>
  * &lt;/simpleType>
  * </pre>
@@ -30,7 +32,11 @@ public enum FramebufferCapabilities {
     UPDATE_IMAGE("UpdateImage"),
     VHWA("VHWA"),
     @XmlEnumValue("VisibleRegion")
-    VISIBLE_REGION("VisibleRegion");
+    VISIBLE_REGION("VisibleRegion"),
+    @XmlEnumValue("RenderCursor")
+    RENDER_CURSOR("RenderCursor"),
+    @XmlEnumValue("MoveCursor")
+    MOVE_CURSOR("MoveCursor");
     private final String value;
 
     FramebufferCapabilities(String v) {
